pub enum Errors {
WrongType(String),
IO(Error),
Rkyv(Error),
KanalSend(SendError),
KanalReceive(ReceiveError),
StreamAlreadyTerminated,
}Expand description
The errors that can be returned from the Shoal client
Variants
WrongType(String)
Attempt to cast a shoal response to the wrong type
IO(Error)
An IO error occured
Rkyv(Error)
An rkyv error
KanalSend(SendError)
An error sending data to a kanal channel
KanalReceive(ReceiveError)
An error receiving data from a kanal channel
StreamAlreadyTerminated
A stream has already ended