Module errors

Module errors 

Any errors tht can be encountered when running Shoal

Enums

ServerError
Any errors tht can be encountered when running Shoal
ShoalError
The errors specific to Shoal server code