ServerError

Enum ServerError 

pub enum ServerError {
Show 14 variants Shoal(ShoalError), IO(Error), GlommioIO { source: Error, op: &'static str, path: Option<PathBuf>, fd: Option<RawFd>, }, GlommioExectorError(ExecutorErrorKind), GlommioBuilderError(BuilderErrorKind), GlommioReactorError(ReactorErrorKind), GlommioTimedOut(Duration), GlommioGeneric(String), Config(ConfigError), Rkyv(Error), IntoSlice(TryFromSliceError), Conversion(Infallible), KanalSend(SendError), KanalRecv(ReceiveError),
}
Any errors tht can be encountered when running Shoal

Variants



Shoal(ShoalError)

An error specific to Shoal code



IO(Error)

An IO error



GlommioIO

A glommio enhanced IO errors

Fields

source: Error
op: &'static str


GlommioExectorError(ExecutorErrorKind)

A glommio executor error



GlommioBuilderError(BuilderErrorKind)

A glommio builder error



GlommioReactorError(ReactorErrorKind)

A glommio reactor error



GlommioTimedOut(Duration)

Glommio time out error



GlommioGeneric(String)

An error from glommio with a generic



Config(ConfigError)

An config parsing error



Rkyv(Error)

An rkyv error



IntoSlice(TryFromSliceError)

An error casting a vec of bytes to a slice



Conversion(Infallible)

A conversion error



KanalSend(SendError)

An error sending a message over a kanal channel



KanalRecv(ReceiveError)

An error receiving a message over a kanal channel