pub struct QueryMetadata {
pub addr: SocketAddr,
pub id: Uuid,
pub index: usize,
pub end: bool,
}Expand description
The metadata about a query from a client
Fields
addr: SocketAddrThe address of the client this query came from
id: UuidThe id for this query
index: usizeThis queries index in the queries vec
end: boolWhether this is the last query in a query bundle
Implementations
Sourceimpl QueryMetadata
impl QueryMetadata
Sourcepub fn new(addr: SocketAddr, id: Uuid, index: usize, end: bool) -> Self
pub fn new(addr: SocketAddr, id: Uuid, index: usize, end: bool) -> Self
Create a new query metadata object
Arguments
addr- The address to respond to this query atid- The id of this queryindex- The index for this query in a bundle of queriesend- Whether this is the last query in a bundle or not