FileSystem

Struct FileSystem 

pub struct FileSystem<T: ShoalTable> {
    pub conf: Conf,
    pub intent_tx: AsyncSender<CompactionJob>,
    pub tasks: FuturesUnordered<Task<Result<(), ServerError>>>,
    /* private fields */
}
Store shoal data in an existing filesytem for persistence

Fields

conf: Conf

The config for shoal

intent_tx: AsyncSender<CompactionJob>

The channel to send intent log compactions on

tasks: FuturesUnordered<Task<Result<(), ServerError>>>

The different tasks spawned by this shards file system storage engine