pub struct PersistentTable<T: ShoalTable, S: ShoalStorage<T>> {
pub partitions: HashMap<u64, Partition<T>>,
/* private fields */
}Expand description
A table that stores data both in memory and on disk
Fields
partitions: HashMap<u64, Partition<T>>The rows in this table
Implementations
Sourceimpl<T: ShoalTable, S: ShoalStorage<T>> PersistentTable<T, S>
impl<T: ShoalTable, S: ShoalStorage<T>> PersistentTable<T, S>
Sourcepub async fn new(
shard_name: &str,
conf: &Conf,
medium_priority: TaskQueueHandle,
) -> Result<Self, ServerError>
pub async fn new( shard_name: &str, conf: &Conf, medium_priority: TaskQueueHandle, ) -> Result<Self, ServerError>
Create a persistent shoal table
Arguments
shard_name- The id of the shard that owns this tableconf- The Shoal config
Sourcepub async fn handle(
&mut self,
meta: QueryMetadata,
query: Query<T>,
) -> Option<(SocketAddr, Response<T>)>
pub async fn handle( &mut self, meta: QueryMetadata, query: Query<T>, ) -> Option<(SocketAddr, Response<T>)>
Cast and handle a serialized query
Arguments
meta- The metadata for this queryquery- The query to execute
Sourcepub async fn flush(&mut self) -> Result<(), ServerError>
pub async fn flush(&mut self) -> Result<(), ServerError>
Flush all pending writes to disk
Sourcepub async fn get_flushed(
&mut self,
) -> Result<&mut Vec<(SocketAddr, Response<T>)>, ServerError>
pub async fn get_flushed( &mut self, ) -> Result<&mut Vec<(SocketAddr, Response<T>)>, ServerError>
Sourcepub async fn shutdown(&mut self) -> Result<(), ServerError>
pub async fn shutdown(&mut self) -> Result<(), ServerError>
Shutdown this table