PersistentTable

Struct PersistentTable 

pub struct PersistentTable<T: ShoalTable, S: ShoalStorage<T>> {
    pub partitions: HashMap<u64, Partition<T>>,
    /* private fields */
}
A table that stores data both in memory and on disk

Fields

partitions: HashMap<u64, Partition<T>>

The rows in this table

Implementations

Source

impl<T: ShoalTable, S: ShoalStorage<T>> PersistentTable<T, S>

pub async fn new( shard_name: &str, conf: &Conf, medium_priority: TaskQueueHandle, ) -> Result<Self, ServerError>

Create a persistent shoal table

Arguments
  • shard_name - The id of the shard that owns this table
  • conf - The Shoal config
pub async fn handle( &mut self, meta: QueryMetadata, query: Query<T>, ) -> Option<(SocketAddr, Response<T>)>

Cast and handle a serialized query

Arguments
  • meta - The metadata for this query
  • query - The query to execute
pub async fn flush(&mut self) -> Result<(), ServerError>

Flush all pending writes to disk

pub async fn get_flushed( &mut self, ) -> Result<&mut Vec<(SocketAddr, Response<T>)>, ServerError>

Get all flushed response actions

Arguments
  • flushed - The flushed actions to return
pub async fn shutdown(&mut self) -> Result<(), ServerError>

Shutdown this table